@@ -23,10 +23,9 @@ def str_padding(length, val):
     return '{0:<{fill}}'.format(val, fill=length)
 
 
-def int_padding(length, val):
+def int_padding(length, val, direction=">"):
     """Formats value giving it left zeros padding up to a total length of 'length'"""
-    return '{0:0>{fill}}'.format(val, fill=length)
-
+    return '{0:0{direction}{fill}}'.format(val, direction=direction, fill=length)
 
 def float_padding(length, val, decimals=2):
     """Pads zeros to left and right to assure proper length and precision"""
@@ -101,6 +100,21 @@ class StringField(FixedWidthField):
     pass
 
 
+class PostalCodeField(FixedWidthField):
+
+    def __init__(self):
+        super(PostalCodeField, self).__init__(length=9)
+
+    def to_record(self, val):
+        if val is None or is_blank_string(val):
+            return str_padding(self.length, " ")
+        try:
+            int(val)
+            return int_padding(self.length, val, "<")
+        except ValueError:
+            return str_padding(self.length, val)
+
+
 class IntegerField(FixedWidthField):
 
     def to_python(self, val):
@@ -131,11 +145,11 @@ class DecimalField(FixedWidthField):
         return float_padding(self.length, val, decimals=self.decimals)
 
 
-class DateField(FixedWidthField):
+class DateTimeField(FixedWidthField):
 
     def __init__(self, length, default=NOT_PROVIDED, format="%Y-%m-%d"):
         self.format = format
-        super(DateField, self).__init__(length, default)
+        super(DateTimeField, self).__init__(length, default)
 
     def to_python(self, val):
         if val is None or is_blank_string(val):
@@ -145,7 +159,7 @@ class DateField(FixedWidthField):
         if isinstance(val, datetime.date):
             return val
 
-        return datetime.datetime.strptime(val, self.format).date()
+        return datetime.datetime.strptime(val, self.format)
 
     def to_record(self, val):
         if not val:
@@ -153,6 +167,15 @@ class DateField(FixedWidthField):
         return val.strftime(self.format)
 
 
+class DateField(DateTimeField):
+
+    def to_python(self, val):
+        result = super(DateField, self).to_python(val)
+        if isinstance(result, datetime.datetime):
+            return result.date()
+        return result
+
+
 class FragmentField(FixedWidthField):
     """
     Allows you to create a field on a record that is itself a complete
