@@ -38,6 +38,10 @@ class PaddingTests(TestCase):
         self.assertEqual("ALM   ", fields.str_padding(6, "ALM"))
         self.assertEqual("5     ", fields.str_padding(6, 5))
 
+    def test_int_right_padding_pads_right_with_zeros(self):
+        self.assertEqual("110000", fields.int_padding(6, 11, "<"))
+        self.assertEqual("110000", fields.int_padding(6, "11", "<"))
+
     def test_int_padding_pads_left_with_zeros(self):
         self.assertEqual("000010", fields.int_padding(6, 10))
         self.assertEqual("000010", fields.int_padding(6, "10"))
@@ -256,6 +260,35 @@ class StringFieldTests(TestCase):
         self.assertEqual("", field.to_python("     "))
 
 
+class PostalCodeFieldTests(TestCase):
+
+    def setUp(self):
+        self.field = fields.PostalCodeField()
+
+    def test_postal_code_field_length_is_set_to_nine(self):
+        self.assertEqual(9, self.field.length)
+
+    def test_to_record_returns_string_of_value_padded_to_length_if_string(self):
+        self.assertEqual("AA       ", self.field.to_record("AA"))
+
+    def test_to_record_returns_padded_blank_string_when_value_is_None(self):
+        self.assertEqual("         ", self.field.to_record(None))
+
+    def test_to_record_returns_number_of_value_padded_to_right_of_length_if_number(self):
+        self.assertEqual("990000000", self.field.to_record(99))
+        self.assertEqual("990000000", self.field.to_record("99"))
+
+    def test_to_python_turns_value_to_string(self):
+        python_val = self.field.to_python("K1A XXX")
+        self.assertEqual("K1A XXX", python_val)
+        self.assertIsInstance(python_val, str)
+
+    def test_to_python_turns_value_to_string_if_integer(self):
+        python_val = self.field.to_python(50401)
+        self.assertEqual("50401", python_val)
+        self.assertIsInstance(python_val, str)
+
+
 class IntegerFieldTests(TestCase):
 
     def test_to_record_returns_string_of_value_padded_to_length(self):
@@ -316,6 +349,17 @@ class DecimalFieldTests(TestCase):
             self.assertEqual(None, field.to_python("0001A"))
 
 
+class DateTimeFieldTests(TestCase):
+
+    def test_to_record_returns_formatted_datetime(self):
+        field = fields.DateTimeField(length=14, format="%Y%m%d%H%M%S")
+        self.assertEqual("20120101010101", field.to_record(datetime(2012, 1, 1, 1, 1, 1)))
+
+    def test_to_model_returns_datetime_object(self):
+        field = fields.DateTimeField(length=14, format="%Y%m%d%H%M%S")
+        self.assertEqual(datetime(2012, 1, 1, 1, 1, 1), field.to_python("20120101010101"))
+
+
 class DateFieldTests(TestCase):
 
     def test_to_record_returns_formatted_date(self):
